=======
Credits
=======

This demonstrator project was initiated as part of Antoine COLLET's thesis (add ref)
between 2020 and 2024. Although the current version of the LBFGSB code was written
in its entirety by Antoine COLLET, Irina SIN and Hervé CHAURIS, researchers
at the Ecole des Mines de Paris and supervisors for this work, are the writters of the
initial prototype (2020) and significantly contributed to the scientific content
and to the derivation of the equations.

Development Lead
----------------

* Antoine Collet <antoine.collet5@gmail.com>

Contributors
------------

None yet. Why not be the first?
